==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/processing/src/main/java/org/apache/druid/query/DruidProcessingIndexesConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.common.config.Configs;
import org.apache.druid.segment.column.ColumnConfig;

import javax.annotation.Nullable;

public class DruidProcessingIndexesConfig
{
  @JsonProperty
  private final double skipValueRangeIndexScale;

  @JsonProperty
  private final double skipValuePredicateIndexScale;

  @JsonCreator
  public DruidProcessingIndexesConfig(
      @JsonProperty("skipValueRangeIndexScale") @Nullable Double skipValueRangeIndexScale,
      @JsonProperty("skipValuePredicateIndexScale") @Nullable Double skipValuePredicateIndexScale
  )
  {
    this.skipValueRangeIndexScale = Configs.valueOrDefault(
        skipValueRangeIndexScale,
        ColumnConfig.DEFAULT_SKIP_VALUE_RANGE_INDEX_SCALE
    );
    this.skipValuePredicateIndexScale = Configs.valueOrDefault(
        skipValuePredicateIndexScale,
        ColumnConfig.DEFAULT_SKIP_VALUE_PREDICATE_INDEX_SCALE
    );
  }

  public DruidProcessingIndexesConfig()
  {
    this(null, null);
  }

  public double getSkipValueRangeIndexScale()
  {
    return skipValueRangeIndexScale;
  }

  public double getSkipValuePredicateIndexScale()
  {
    return skipValuePredicateIndexScale;
  }
}

==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/processing/src/main/java/org/apache/druid/query/DruidProcessingIndexesConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.common.config.Configs;
import org.apache.druid.segment.column.ColumnConfig;

import javax.annotation.Nullable;

public class DruidProcessingIndexesConfig
{
  @JsonProperty
  private final double skipValueRangeIndexScale;

  @JsonCreator
  public DruidProcessingIndexesConfig(
      @JsonProperty("skipValueRangeIndexScale") @Nullable Double skipValueRangeIndexScale
  )
  {
    this.skipValueRangeIndexScale = Configs.valueOrDefault(
        skipValueRangeIndexScale,
        ColumnConfig.DEFAULT_SKIP_VALUE_RANGE_INDEX_SCALE
    );
  }

  public DruidProcessingIndexesConfig()
  {
    this(null);
  }

  public double getSkipValueRangeIndexScale()
  {
    return skipValueRangeIndexScale;
  }
}
